aboutsummaryrefslogtreecommitdiff
path: root/lib/Frontend/LogDiagnosticPrinter.cpp
diff options
context:
space:
mode:
authorDavid Blaikie <dblaikie@gmail.com>2011-09-25 23:39:51 +0000
committerDavid Blaikie <dblaikie@gmail.com>2011-09-25 23:39:51 +0000
commit78ad0b98848c17a0a11847fa1d456e2dfec8aa2f (patch)
tree80cd0f2f026558c7fdb2a0ab4a7b7595c006408f /lib/Frontend/LogDiagnosticPrinter.cpp
parentd6471f7c1921c7802804ce3ff6fe9768310f72b9 (diff)
Rename DiagnosticClient to DiagnosticConsumer as per issue 5397
git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@140479 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Frontend/LogDiagnosticPrinter.cpp')
-rw-r--r--lib/Frontend/LogDiagnosticPrinter.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/Frontend/LogDiagnosticPrinter.cpp b/lib/Frontend/LogDiagnosticPrinter.cpp
index 00cd85dca0..1f64134d3a 100644
--- a/lib/Frontend/LogDiagnosticPrinter.cpp
+++ b/lib/Frontend/LogDiagnosticPrinter.cpp
@@ -42,9 +42,9 @@ void LogDiagnosticPrinter::EndSourceFile() {
// We emit all the diagnostics in EndSourceFile. However, we don't emit any
// entry if no diagnostics were present.
//
// Note that DiagnosticClient has no "end-of-compilation" callback, so we will
// miss any diagnostics which are emitted after and outside the translation
// unit processing.
if (Entries.empty())
return;
@@ -96,7 +96,7 @@ void LogDiagnosticPrinter::EndSourceFile() {
void LogDiagnosticPrinter::HandleDiagnostic(DiagnosticsEngine::Level Level,
const DiagnosticInfo &Info) {
// Default implementation (Warnings/errors count).
- DiagnosticClient::HandleDiagnostic(Level, Info);
+ DiagnosticConsumer::HandleDiagnostic(Level, Info);
// Initialize the main file name, if we haven't already fetched it.
if (MainFilename.empty() && Info.hasSourceManager()) {
@@ -42,9 +42,9 @@ void LogDiagnosticPrinter::EndSourceFile() {
// entry if no diagnostics were present.
//
- // Note that DiagnosticClient has no "end-of-compilation" callback, so we will
- // miss any diagnostics which are emitted after and outside the translation
- // unit processing.
+ // Note that DiagnosticConsumer has no "end-of-compilation" callback, so we
+ // will miss any diagnostics which are emitted after and outside the
+ // translation unit processing.
if (Entries.empty())
return;